@@ -1,17 +1,18 @@
 import type QUnit from 'qunit'
-// @ts-ignore
-import * as lib from '#dist/webapi'
 import * as env from './env.js'
+import type * as jose from '../src/index.js'
+import random from './random.js'
+import roundtrip from './encrypt.js'
 
-export default (QUnit: QUnit) => {
+export default (QUnit: QUnit, lib: typeof jose) => {
   const { module, test } = QUnit
   module('aeskw.ts')
 
   type Vector = [string, boolean]
   const algorithms: Vector[] = [
-    ['A128KW', true],
-    ['A192KW', !env.isChromium],
-    ['A256KW', true],
+    ['A128KW', !env.isElectron],
+    ['A192KW', !(env.isChromium || env.isElectron)],
+    ['A256KW', !env.isElectron],
     ['A128GCMKW', true],
     ['A192GCMKW', !env.isChromium],
     ['A256GCMKW', true],
@@ -27,19 +28,17 @@ export default (QUnit: QUnit) => {
     return result
   }
 
+  function secretsFor(alg: string) {
+    return [lib.generateSecret(alg), random(parseInt(alg.slice(1, 4), 10) >> 3)]
+  }
+
   for (const vector of algorithms) {
     const [alg, works] = vector
 
     const execute = async (t: typeof QUnit.assert) => {
-      const secret = await lib.generateSecret(alg)
-
-      const jwe = await new lib.FlattenedEncrypt(crypto.getRandomValues(new Uint8Array(32)))
-        .setProtectedHeader({ alg, enc: 'A256GCM' })
-        .setAdditionalAuthenticatedData(crypto.getRandomValues(new Uint8Array(32)))
-        .encrypt(secret)
-
-      await lib.flattenedDecrypt(jwe, secret)
-      t.ok(1)
+      for await (const secret of secretsFor(alg)) {
+        await roundtrip(t, lib, alg, 'A128GCM', secret)
+      }
     }
 
     if (works) {
