@@ -1,17 +1,17 @@
 import type QUnit from 'qunit'
-// @ts-ignore
-import * as lib from '#dist/webapi'
 import * as env from './env.js'
+import type * as jose from '../src/index.js'
+import roundtrip from './encrypt.js'
 
-export default (QUnit: QUnit) => {
+export default (QUnit: QUnit, lib: typeof jose) => {
   const { module, test } = QUnit
   module('pbes2.ts')
 
   type Vector = [string, boolean]
   const algorithms: Vector[] = [
-    ['PBES2-HS256+A128KW', true],
-    ['PBES2-HS384+A192KW', !env.isChromium],
-    ['PBES2-HS512+A256KW', true],
+    ['PBES2-HS256+A128KW', !env.isElectron],
+    ['PBES2-HS384+A192KW', !env.isChromium && !env.isElectron],
+    ['PBES2-HS512+A256KW', !env.isElectron],
   ]
 
   function title(vector: Vector) {
@@ -29,14 +29,7 @@ export default (QUnit: QUnit) => {
 
     const execute = async (t: typeof QUnit.assert) => {
       const password = new TextEncoder().encode('letmein')
-
-      const jwe = await new lib.FlattenedEncrypt(crypto.getRandomValues(new Uint8Array(32)))
-        .setProtectedHeader({ alg, enc: 'A256GCM' })
-        .setAdditionalAuthenticatedData(crypto.getRandomValues(new Uint8Array(32)))
-        .encrypt(password)
-
-      await lib.flattenedDecrypt(jwe, password)
-      t.ok(1)
+      await roundtrip(t, lib, alg, 'A128GCM', password)
     }
 
     if (works) {
