@@ -1,14 +1,15 @@
 import type QUnit from 'qunit'
-// @ts-ignore
-import * as lib from '#dist/webapi'
+import * as env from './env.js'
+import type * as jose from '../src/index.js'
+import roundtrip from './encrypt.js'
 
-export default (QUnit: QUnit) => {
+export default (QUnit: QUnit, lib: typeof jose) => {
   const { module, test } = QUnit
   module('rsaes.ts')
 
   type Vector = [string, boolean]
   const algorithms: Vector[] = [
-    ['RSA1_5', false],
+    ['RSA1_5', env.isNodeCrypto || env.isElectron],
     ['RSA-OAEP', true],
     ['RSA-OAEP-256', true],
     ['RSA-OAEP-384', true],
@@ -29,15 +30,8 @@ export default (QUnit: QUnit) => {
     const [alg, works] = vector
 
     const execute = async (t: typeof QUnit.assert) => {
-      const { privateKey, publicKey } = await lib.generateKeyPair(alg)
-
-      const jwe = await new lib.FlattenedEncrypt(crypto.getRandomValues(new Uint8Array(32)))
-        .setProtectedHeader({ alg, enc: 'A256GCM' })
-        .setAdditionalAuthenticatedData(crypto.getRandomValues(new Uint8Array(32)))
-        .encrypt(publicKey)
-
-      await lib.flattenedDecrypt(jwe, privateKey)
-      t.ok(1)
+      const kp = await lib.generateKeyPair(alg)
+      await roundtrip(t, lib, alg, 'A128GCM', kp)
     }
 
     if (works) {
