@@ -1,6 +1,15 @@
 import type QUnit from 'qunit'
+import type * as jose from '../src/index.js'
 
-export default async (QUnit: QUnit, done?: (details: QUnit.DoneDetails) => void) => {
+const skipFetch =
+  // @ts-ignore
+  typeof fetch === 'undefined' || (typeof process !== 'undefined' && 'CITGM' in process.env)
+
+export default async (
+  QUnit: QUnit,
+  lib: typeof jose,
+  done: (details: QUnit.DoneDetails) => void,
+) => {
   // @ts-ignore
   QUnit.reporters.tap.init(QUnit)
   QUnit.config.autostart = false
@@ -10,19 +19,18 @@ export default async (QUnit: QUnit, done?: (details: QUnit.DoneDetails) => void)
     import('./aeskw.js'),
     import('./cookbook.js'),
     import('./ecdh.js'),
+    import('./generate_options.js'),
     import('./hmac.js'),
     import('./jwk.js'),
-    import('./jwks.js'),
+    !skipFetch ? import('./jwks.js') : import('./noop.js'),
     import('./jws.js'),
-    import('./pem.js'),
     import('./pbes2.js'),
+    import('./pem.js'),
     import('./rsaes.js'),
   ])
   for (const { default: module } of modules) {
-    await module(QUnit)
+    await module(QUnit, lib)
   }
   QUnit.start()
-  if (done) {
-    QUnit.done(done)
-  }
+  QUnit.done(done)
 }
